@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Plowshare.  If not, see <http://www.gnu.org/licenses/>.
 
-declare -r VERSION='v2.1.5 (2016-09-17)'
+declare -r VERSION='v2.1.6 (2016-11-01)'
 
 declare -r EARLY_OPTIONS="
 HELP,h,help,,Show help info and exit
@@ -268,7 +268,7 @@ if [ ${#COMMAND_LINE_ARGS[@]} -eq 0 ]; then
     exit $ERR_BAD_COMMAND_LINE
 fi
 
-set_exit_trap
+core_init 'plowlist'
 
 for URL in "${COMMAND_LINE_ARGS[@]}"; do
     LRETVAL=0
