@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Plowshare.  If not, see <http://www.gnu.org/licenses/>.
 
-declare -r VERSION='v2.1.5 (2016-09-17)'
+declare -r VERSION='v2.1.6 (2016-11-01)'
 
 # Default repository source
 declare -r LEGACY_MODULES='https://github.com/mcrapet/plowshare-modules-legacy.git'
@@ -317,7 +317,7 @@ if check_exec 'git'; then
     log_report "[git ] $(git --version)"
 fi
 
-set_exit_trap
+core_init 'plowmod'
 
 declare -a RETVALS
 
