@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Plowshare.  If not, see <http://www.gnu.org/licenses/>.
 
-declare -r VERSION='v2.1.5 (2016-09-17)'
+declare -r VERSION='v2.1.6 (2016-11-01)'
 
 declare -r EARLY_OPTIONS="
 HELP,h,help,,Show help info and exit
@@ -427,7 +427,7 @@ fi
 # Remove module name from argument list
 unset COMMAND_LINE_ARGS[0]
 
-set_exit_trap
+core_init 'plowup'
 
 UCOOKIE=$(create_tempfile) || exit
 URESULT=$(create_tempfile) || exit
